pub struct SkillRegistry { /* private fields */ }Expand description
A registry of loaded skills with tag and trigger indices.
Implementations
Sourceimpl SkillRegistry
impl SkillRegistry
Sourcepub fn add(&mut self, skill: Skill, tier: SkillTier)
pub fn add(&mut self, skill: Skill, tier: SkillTier)
Add a skill to the registry with the given tier.
Find skills matching any of the given tags, sorted by tier (desc) then priority (desc).
Sourcepub fn find_by_trigger(&self, query: &str) -> Vec<&Skill>
pub fn find_by_trigger(&self, query: &str) -> Vec<&Skill>
Find skills whose trigger keywords match the query (case-insensitive).